@@ -3,8 +3,8 @@
 #' Visualize the main items of three fields (e.g. authors, keywords, journals), and how they are related through a Sankey diagram.
 #' 
 #' @param M is a bibliographic data frame obtained by the converting function \code{\link{convert2df}}.
-#'        It is a data matrix with cases corresponding to manuscripts and variables to Field Tag in the original SCOPUS and Thomson Reuters' ISI Web of Knowledge file.
-#' @param fields is a character vector. It indicates the fields to analize using the standard WoS field tags. 
+#'        It is a data matrix with cases corresponding to manuscripts and variables to Field Tag in the original SCOPUS and Clarivate Analytics WoS file.
+#' @param fields is a character vector. It indicates the fields to analyze using the standard WoS field tags. 
 #'        Default is \code{fields = c("AU","DE", "SO")}.
 #' @param n is a integer vector. It indicates how many items to plot, for each of the three fields. 
 #'        Default is \code{n = c(20, 20, 20)}
@@ -46,27 +46,26 @@ threeFieldsPlot <- function(M, fields=c("AU","DE","SO"),n=c(20,20,20), width=120
   
   ### Document x Attribute matrix Field LEFT
   WL=cocMatrix(M,fields[1], binary=Binary[1])
-  n1=n[1]
+  n1=min(n[1],ncol(WL))
   TopL=names(sort(Matrix::colSums(WL),decreasing = TRUE))[1:n1]
   WL=WL[,TopL]
   
   ### Document x Attribute matrix Field MIDDLE
   WM=cocMatrix(M,fields[2], binary=Binary[2])
-  n2=n[2]
+  n2=min(n[2],ncol(WM))
   TopM=names(sort(Matrix::colSums(WM),decreasing = TRUE))[1:n2]
   WM=WM[,TopM]
   
   ### Document x Attribute matrix Field RIGHT
   WR=cocMatrix(M,fields[3], binary=Binary[3])
-  n3=n[3]
+  n3=min(n[3],ncol(WR))
   TopR=names(sort(Matrix::colSums(WR),decreasing = TRUE))[1:n3]
   WR=WR[,TopR]
   
   ### Co-Occurrence Matrices
   LM=Matrix::crossprod(WL,WM)
   MR=Matrix::crossprod(WM,WR)
-  
-  
+
   row.names(LM)=1:n1
   colnames(LM)=row.names(MR)=(n1+1):(n2+n1)
   colnames(MR)=(n2+n1+1):(n1+n2+n3)
