@@ -9,7 +9,7 @@ library(bibliometrix)   ### load bibliometrix package
 
 ## ----Data loading--------------------------------------------------------
 
-D <- readFiles("http://www.bibliometrix.org/datasets/savedrecs.bib")
+D <- readFiles("https://www.bibliometrix.org/datasets/savedrecs.bib")
 
 ## ----Data converting-----------------------------------------------------
 M <- convert2df(D, dbsource = "isi", format = "bibtex")
